@@ -22,7 +22,7 @@ from gevent.socket import wait_read
 
 from xnet.debug import pdb
 
-gevent.monkey.patch_socket()
+gevent.monkey.patch_all(thread=False)
 
 DEVELOPMENT = 1
 
