@@ -17,6 +17,7 @@ import OpenSSL
 import gevent
 
 from xnet.tools import Tool
+from xnet.net.ipv4 import IPRangeIterator
 
 
 class SSLInfoException(Exception):
@@ -35,6 +36,18 @@ class SSLInfoTool(Tool):
             dict(dest='cn', action='store_true'))
     ]
 
+    @classmethod
+    def __massage__(self, iterator):
+        for item in iterator:
+            item = item.strip()
+            try:
+                iprangeiter = IPRangeIterator(item)
+            except ValueError:
+                yield item
+            else:
+                for ip in iprangeiter:
+                    yield str(ip)
+
     def __parse__(self, line, iterator):
         result = {}
         host = line.strip()
@@ -53,7 +66,7 @@ class SSLInfoTool(Tool):
 
     def __action__(self, parse_result):
         result = {}
-        addr = parse_result['addr']
+        self._addr = addr = parse_result['addr']
         try:
             cert = ssl.get_server_certificate(addr)
             x509 = OpenSSL.crypto.load_certificate(OpenSSL.crypto.FILETYPE_PEM, cert)
@@ -74,14 +87,6 @@ class SSLInfoTool(Tool):
             self.set_error(errmsg)
             self.stderr = True
             return None
-        except gevent.GreenletExit:
-            #
-            # happens in BT, not OSX
-            #
-            self.set_error('TIMEOUT')
-            self.stderr = True
-            print 'TIMEOUT'
-            return None
         except Exception, e:
             errmsg = addr[0] + ' ' + str(e) + '\n'
             sys.stderr.write(errmsg)
@@ -103,6 +108,9 @@ class SSLInfoTool(Tool):
                 output = output[:-1]
         return output
 
+    def __timeout__(self):
+        return 'timeout {0} {1}\n'.format(*self._addr)
+
 
 def main():
     import xnet.tools
